X-Git-Url: https://git.xinqibao.xyz/st.git/blobdiff_plain/bef599bb279e6c9b08853ceebefade066e362c48..39f28b18b76b9dc8353ae399cb8a99f13f9de2c2:/config.def.h?ds=sidebyside

diff --git a/config.def.h b/config.def.h
index 6487406..2a7e098 100644
--- a/config.def.h
+++ b/config.def.h
@@ -41,7 +41,7 @@ static unsigned int blinktimeout = 800;
  * bell volume. It must be a value between -100 and 100. Use 0 for disabling
  * it
  */
-static int bellvolume = 1;
+static int bellvolume = 0;
 
 /* TERM value */
 static char termname[] = "st-256color";
@@ -146,10 +146,10 @@ static Shortcut shortcuts[] = {
 static KeySym mappedkeys[] = { -1 };
 
 /*
  * Which bits of the state should be ignored. By default the state bit for the
  * keyboard layout (XK_SWITCH_MOD) is ignored.
  */
-uint ignoremod = XK_SWITCH_MOD;
+static uint ignoremod = Mod2Mask|XK_SWITCH_MOD;
 
 /* key, mask, output, keypad, cursor, crlf */
 static Key key[] = {
@@ -146,10 +146,10 @@ static Shortcut shortcuts[] = {
 
 /*
- * Which bits of the state should be ignored. By default the state bit for the
- * keyboard layout (XK_SWITCH_MOD) is ignored.
+ * State bits to ignore when matching key or button events.  By default,
+ * numlock (Mod2Mask) and keyboard layout (XK_SWITCH_MOD) are ignored.
  */